"""cz_legacy."""

from .cz_legacy import _LegacyCz as discover_this  # noqa: N813

__version__ = '0.1.6'
__pkg_name__ = 'cz_legacy'

__all__ = ('discover_this',)
"""Make the _LegacyCz class discoverable by commitizen."""
